mpl\_interactions.panhandler
============================

.. currentmodule:: mpl_interactions

.. autoclass:: panhandler

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~panhandler.__init__
      ~panhandler.press
      ~panhandler.release
   
   

   
   
   